@@ -32,7 +32,7 @@
  * @ref TextView "TextView".
  *
  * See also the
- * <a href="https://library.gnome.org/devel/gtkmm-tutorial/stable/">Programming
+ * <a href="https://gnome.pages.gitlab.gnome.org/gtkmm-documentation/">Programming
  * with gtkmm</a> book.
  *
  * @section features Features
@@ -109,6 +109,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/actionable.h>
 #include <gtkmm/actionbar.h>
 #include <gtkmm/adjustment.h>
+#include <gtkmm/alertdialog.h>
 #include <gtkmm/appchooserbutton.h>
 #include <gtkmm/appchooserdialog.h>
 #include <gtkmm/appchooserwidget.h>
@@ -116,6 +117,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/applicationwindow.h>
 #include <gtkmm/aspectframe.h>
 #include <gtkmm/assistant.h>
+#include <gtkmm/atcontext.h>
 #include <gtkmm/binlayout.h>
 #include <gtkmm/boolfilter.h>
 #include <gtkmm/border.h>
@@ -142,7 +144,9 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/colorbutton.h>
 #include <gtkmm/colorchooser.h>
 #include <gtkmm/colorchooserdialog.h>
+#include <gtkmm/colordialogbutton.h>
 #include <gtkmm/columnview.h>
+#include <gtkmm/columnviewsorter.h>
 #include <gtkmm/combobox.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/constraintlayout.h>
@@ -162,6 +166,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/entry.h>
 #include <gtkmm/expander.h>
 #include <gtkmm/enums.h>
+#include <gtkmm/error.h>
 #include <gtkmm/eventcontroller.h>
 #include <gtkmm/eventcontrollerfocus.h>
 #include <gtkmm/eventcontrollerkey.h>
@@ -171,7 +176,9 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/filechoosernative.h>
 #include <gtkmm/filechooserwidget.h>
+#include <gtkmm/filedialog.h>
 #include <gtkmm/filefilter.h>
+#include <gtkmm/filelauncher.h>
 #include <gtkmm/filterlistmodel.h>
 #include <gtkmm/fixed.h>
 #include <gtkmm/flattenlistmodel.h>
@@ -181,6 +188,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/fontchooser.h>
 #include <gtkmm/fontchooserdialog.h>
 #include <gtkmm/fontchooserwidget.h>
+#include <gtkmm/fontdialogbutton.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/gesture.h>
 #include <gtkmm/gestureclick.h>
@@ -202,6 +210,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/iconview.h>
 #include <gtkmm/image.h>
 #include <gtkmm/infobar.h>
+#include <gtkmm/inscription.h>
 #include <gtkmm/calendar.h>
 #include <gtkmm/label.h>
 #include <gtkmm/layoutchild.h>
@@ -308,6 +317,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/treestore.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/treeviewcolumn.h>
+#include <gtkmm/urilauncher.h>
 #include <gtkmm/version.h>
 #include <gtkmm/video.h>
 #include <gtkmm/viewport.h>
